Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/windirstat/llfio.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNiall Douglas (s [underscore] sourceforge {at} nedprod [dot] com) <spamtrap@nedprod.com>2018-07-06 21:07:06 +0300
committerNiall Douglas (s [underscore] sourceforge {at} nedprod [dot] com) <spamtrap@nedprod.com>2018-07-06 21:07:06 +0300
commit302db08dd88a5e77fb40103ed632be1e72066bf1 (patch)
treef59f570917859f7f02c354c86667abf2721d9a85 /include/llfio/v2.0/utils.hpp
parent6efe2493a65540d3f484a8b7f27d5298d49c9da4 (diff)
More afio => llfio
Diffstat (limited to 'include/llfio/v2.0/utils.hpp')
-rw-r--r--include/llfio/v2.0/utils.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llfio/v2.0/utils.hpp b/include/llfio/v2.0/utils.hpp
index 6826e776..8d731016 100644
--- a/include/llfio/v2.0/utils.hpp
+++ b/include/llfio/v2.0/utils.hpp
@@ -26,7 +26,7 @@ Distributed under the Boost Software License, Version 1.0.
#define LLFIO_UTILS_H
#ifndef LLFIO_CONFIG_HPP
#error You must include the master afio.hpp, not individual header files directly
#endif
#include "config.hpp"
@@ -197,7 +197,7 @@ namespace utils
unmodified.
A particularly useful combination with this allocator is with the
- page_sizes() member function of __afio_dispatcher__. This will return which
+ page_sizes() member function of __llfio_dispatcher__. This will return which
pages sizes are possible, and which page sizes are enabled for this user. If
writing a file copy routine for example, using this allocator with the
largest page size as the copy chunk makes a great deal of sense.
@@ -26,7 +26,7 @@ Distributed under the Boost Software License, Version 1.0.
#define LLFIO_UTILS_H
#ifndef LLFIO_CONFIG_HPP
-#error You must include the master afio.hpp, not individual header files directly
+#error You must include the master llfio.hpp, not individual header files directly
#endif
#include "config.hpp"